ABlog v0.9 released
===================

.. post:: Feb 17, 2018
   :author: Nabil
   :category: Release
   :location: World


ABlog v0.9.0 is released with the main focus being to support the latest version of Sphinx.
This also moves the main development from `Abakan`_ to `SunPy`_.

This has merged in all current (at time of writing, 6) open PRs to the original repository.

These are:

`fix(commands): Update command arguments so patterns works correctly <https://github.com/abakan/ablog/pull/96>`_
from `rayalan <https://github.com/rayalan>`_.

`Fix couple of bugs with latest stable Sphinx <https://github.com/abakan/ablog/pull/93>`_ from `tadeboro <https://github.com/tadeboro>`_.

`don't use fancy quotes in the conf.py template <https://github.com/abakan/ablog/pull/87>`_ from `tiwo <https://github.com/tiwo>`_.

`Pass through additional Sphinx options and fix a typo <https://github.com/abakan/ablog/pull/84>`_ from `ahrbel <https://github.com/ahrbe1>`_.

`fix #78 (ImportError: cannot import name make_admonition in Sphinx 1.6) <https://github.com/abakan/ablog/pull/79>`_ from `lsaffre <https://github.com/lsaffre>`_.

`Raise exception when title is missing <https://github.com/abakan/ablog/pull/76>`_ from `rgrinberg <https://github.com/rgrinberg>`_.


.. _Abakan: https://github.com/abakan/ablog
.. _SunPy: https://github.com/sunpy/ablog

ABlog v0.9.1 released
=====================

.. post:: March 2, 2018
   :author: Nabil
   :category: Release
   :location: World

Minor update to remove Ablog{}.format(python_number) exes

ABlog v0.9.2 released
=====================

.. post:: March 4, 2018
   :author: Nabil
   :category: Release
   :location: World

Fixed Windows String issue

ABlog v0.9.3 released
=====================

.. post:: October 30, 2018
   :author: Nabil
   :category: Release
   :location: World

Added example on how to use writing blog posts in Jupyter notebooks.
Several fixes provived by `anzawatta`, sorry I was late to release these!
